@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-############################ Copyrights and license ############################
+# ########################## Copyrights and license ############################
 #                                                                              #
 # Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Ed Jackson <ed.jackson@gmail.com>                             #
@@ -23,7 +23,7 @@
 # You should have received a copy of the GNU Lesser General Public License     #
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
-################################################################################
+# ##############################################################################
 
 import urllib
 import pickle
@@ -188,15 +188,16 @@ class Github(object):
         )
         return github.Organization.Organization(self.__requester, headers, data, completed=True)
 
-    def get_repo(self, full_name):
+    def get_repo(self, full_name_or_id):
         """
-        :calls: `GET /repos/:owner/:repo <http://developer.github.com/v3/repos>`_
+        :calls: `GET /repos/:owner/:repo <http://developer.github.com/v3/repos>`_ or `GET /repositories/:id <http://developer.github.com/v3/repos>`_
         :rtype: :class:`github.Repository.Repository`
         """
-        assert isinstance(full_name, (str, unicode)), full_name
+        assert isinstance(full_name_or_id, (str, unicode, int)), full_name_or_id
+        url_base = "/repositories/" if isinstance(full_name_or_id, int) else "/repos/"
         headers, data = self.__requester.requestJsonAndCheck(
             "GET",
-            "/repos/" + full_name
+            "%s%s" % (url_base, full_name_or_id)
         )
         return Repository.Repository(self.__requester, headers, data, completed=True)
 
@@ -301,15 +302,15 @@ class Github(object):
         """
         assert isinstance(query, (str, unicode)), query
         url_parameters = dict()
-        if sort is not github.GithubObject.NotSet:
+        if sort is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
             assert sort in ('stars', 'forks', 'updated'), sort
             url_parameters["sort"] = sort
-        if order is not github.GithubObject.NotSet:
+        if order is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
             assert order in ('asc', 'desc'), order
             url_parameters["order"] = order
 
         query_chunks = []
-        if query:
+        if query:  # pragma no branch (Should be covered)
             query_chunks.append(query)
 
         for qualifier, value in qualifiers.items():
@@ -379,7 +380,7 @@ class Github(object):
             url_parameters["order"] = order
 
         query_chunks = []
-        if query:
+        if query:  # pragma no branch (Should be covered)
             query_chunks.append(query)
 
         for qualifier, value in qualifiers.items():
@@ -406,15 +407,15 @@ class Github(object):
         """
         assert isinstance(query, (str, unicode)), query
         url_parameters = dict()
-        if sort is not github.GithubObject.NotSet:
+        if sort is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
             assert sort in ('indexed',), sort
             url_parameters["sort"] = sort
-        if order is not github.GithubObject.NotSet:
+        if order is not github.GithubObject.NotSet:  # pragma no branch (Should be covered)
             assert order in ('asc', 'desc'), order
             url_parameters["order"] = order
 
         query_chunks = []
-        if query:
+        if query:  # pragma no branch (Should be covered)
             query_chunks.append(query)
 
         for qualifier, value in qualifiers.items():
